import express from "express";

const router = express.Router();
import { EnterPatientDetails, EnterPersonalDetails, Otp, UploadProfileImage, completeRegistration, create1RegistrationDetails, deletePatient, forgotPassword, getAllPatient, loginPatient, register, verifyOtp } from "./PatientController.js";
import { isAuthenticatedPatient } from "../../middlewares/PatientAuth.js";
import { authorizeRoles, isAuthenticatedUser } from "../../middlewares/auth.js";


router.post('/register', register);
router.post('/verify-otp', verifyOtp);
router.post('/login', loginPatient);


router.post('/rgstr_details-p1', isAuthenticatedPatient, create1RegistrationDetails);
router.post('/rgstr_details-p2', isAuthenticatedPatient, EnterPatientDetails);
router.post('/rgstr_psrnl_details-p3', isAuthenticatedPatient, EnterPersonalDetails);

router.get('/getAll', isAuthenticatedUser, authorizeRoles("admin"), getAllPatient);

router.post('/complete-registration', completeRegistration);

router.post('/forgot-password', forgotPassword);
router.post('/profile-image/upload', isAuthenticatedPatient, UploadProfileImage);
//delete Patient
router.delete('/delete/:id', isAuthenticatedUser, authorizeRoles("admin"), deletePatient);





router.get('/otp', Otp);


export default router;
